==> vtk-v1.3.x.zip: vtk-v1.3.x/common/vtkPixmap.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPixmap.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-1996 Ken Martin, Will Schroeder, Bill Lorensen.

This software is copyrighted by Ken Martin, Will Schroeder and Bill Lorensen.
The following terms apply to all files associated with the software unless
explicitly disclaimed in individual files. This copyright specifically does
not apply to the related textbook "The Visualization Toolkit" ISBN
013199837-4 published by Prentice Hall which is covered by its own copyright.

The authors hereby grant permission to use, copy, and distribute this
software and its documentation for any purpose, provided that existing
copyright notices are retained in all copies and that this notice is included
verbatim in any distributions. Additionally, the authors grant permission to
modify this software and its documentation for any purpose, provided that
such modifications are not distributed without the explicit consent of the
authors and that existing copyright notices are retained in all copies. Some
of the algorithms implemented by this software are patented, observe all
applicable patent law.

IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY DERIVATIVES THEREOF,
EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE IS PROVIDED ON AN
"AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.


=========================================================================*/
#include "vtkPixmap.h"

vtkScalars *vtkPixmap::MakeObject(int sze, int ext)
{
  return new vtkPixmap(sze,ext);
}

// Description:
// Deep copy of scalars.
vtkPixmap& vtkPixmap::operator=(const vtkPixmap& fs)
{
  this->S = fs.S;
  return *this;
}

// Description:
// Return a rgba color at array location i.
unsigned char *vtkPixmap::GetColor(int i) 
{
  static unsigned char rgba[4];
  unsigned char *_rgb;
  _rgb = this->S.GetPtr(3*i);
  rgba[0] = _rgb[0];
  rgba[1] = _rgb[1];
  rgba[2] = _rgb[2];
  rgba[3] = 255;

  return rgba;
}

// Description:
// Copy rgba components into user provided array rgb[4] for specified
// point id. 
void vtkPixmap::GetColor(int id, unsigned char rgba[4])
{
  unsigned char *_rgb;

  _rgb = this->S.GetPtr(3*id);
  rgba[0] = _rgb[0];
  rgba[1] = _rgb[1];
  rgba[2] = _rgb[2];
  rgba[3] = 255;
}

==> vtk-v2.0.x.zip: vtk-v2.0.x/common/vtkPixmap.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPixmap.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-1998 Ken Martin, Will Schroeder, Bill Lorensen.

This software is copyrighted by Ken Martin, Will Schroeder and Bill Lorensen.
The following terms apply to all files associated with the software unless
explicitly disclaimed in individual files. This copyright specifically does
not apply to the related textbook "The Visualization Toolkit" ISBN
013199837-4 published by Prentice Hall which is covered by its own copyright.

The authors hereby grant permission to use, copy, and distribute this
software and its documentation for any purpose, provided that existing
copyright notices are retained in all copies and that this notice is included
verbatim in any distributions. Additionally, the authors grant permission to
modify this software and its documentation for any purpose, provided that
such modifications are not distributed without the explicit consent of the
authors and that existing copyright notices are retained in all copies. Some
of the algorithms implemented by this software are patented, observe all
applicable patent law.

IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY DERIVATIVES THEREOF,
EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE IS PROVIDED ON AN
"AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.


=========================================================================*/
#include "vtkPixmap.h"

vtkPixmap::vtkPixmap()
{
  this->S = vtkUnsignedCharArray::New();
}

vtkPixmap::vtkPixmap(const vtkPixmap& fs)
{
  this->S = vtkUnsignedCharArray::New();
  *(this->S) = *(fs.S);
}

vtkPixmap::vtkPixmap(const int sz, const int ext)
{
  this->S = vtkUnsignedCharArray::New();
  this->S->Allocate(sz, ext);
}

vtkPixmap::~vtkPixmap()
{
  this->S->Delete();
}



vtkScalars *vtkPixmap::MakeObject(int sze, int ext)
{
  return new vtkPixmap(sze,ext);
}

// Description:
// Deep copy of scalars.
vtkPixmap& vtkPixmap::operator=(const vtkPixmap& fs)
{
  *(this->S) = *(fs.S);
  return *this;
}

// Description:
// Return a rgba color at array location i.
unsigned char *vtkPixmap::GetColor(int i) 
{
  static unsigned char rgba[4];
  unsigned char *_rgb;
  _rgb = this->S->GetPointer(3*i);
  rgba[0] = _rgb[0];
  rgba[1] = _rgb[1];
  rgba[2] = _rgb[2];
  rgba[3] = 255;

  return rgba;
}

void vtkPixmap::SetNumberOfColors(int number)
{
  this->S->SetNumberOfValues(number*3);
}

// Description:
// Copy rgba components into user provided array rgb[4] for specified
// point id. 
void vtkPixmap::GetColor(int id, unsigned char rgba[4])
{
  unsigned char *_rgb;

  _rgb = this->S->GetPointer(3*id);
  rgba[0] = _rgb[0];
  rgba[1] = _rgb[1];
  rgba[2] = _rgb[2];
  rgba[3] = 255;
}
